import { TxStatus } from "./dbTypes";
import { RenderLogger } from "./logger";
export type TransferType = "open_compute_rewards" | "node_operator_rewards" | "upgrade_rewards";
export interface Transfer {
    id?: bigint;
    solKey?: string;
    solTx?: string;
    sqTx?: string;
    txStatus?: TxStatus;
    createdAt?: Date;
    payedAt?: Date;
    amountDue: bigint;
    amountPayed?: bigint;
    operatorRewards?: NodeOperatorRewardsTransfer;
    computeClientRewards?: ComputeClientsRewardsTransfer;
    upgradeRewards?: UpgradeRewardsTransfer;
}
export interface UpgradeRewardsTransfer {
    epochId: number;
    epochStartTime: Date;
    points: bigint;
}
export interface NodeOperatorRewardsTransfer {
    epochId: number;
    startTime: Date;
    endTime: Date;
}
export interface ComputeClientsRewardsTransfer {
    epochId: number;
    deviceId: string;
}
export interface PgClient {
    fetchInfoForEpoch(epochId: bigint): Promise<{
        jobIds: number[];
        totalRndr: bigint;
    }>;
    payoutTransfersSquads(ts: Record<string, bigint>, payedAt: Date, solTx: string, sqTx: string): Promise<void>;
    updateSqTx(tx: string, status: TxStatus): Promise<void>;
    setSqTx(transferIds: bigint[], sqTx: string): Promise<void>;
    getOutstanding(f: {
        typ: TransferType;
    }): Promise<Record<string, bigint>>;
    createTransfers(transfers: Transfer[]): Promise<void>;
    fetchTransfers(f: {
        epochId?: number;
        payed?: boolean;
        typ: TransferType;
        status?: TxStatus | "notx";
        sort?: "solKey";
    }): Promise<Transfer[]>;
    payoutTransferSq(id: bigint, payedAt: Date, solTx: string, amtPayed: bigint, sqTx: string): Promise<void>;
    payoutTransfer(id: bigint, payedAt: Date, solTx: string, amtPayed: bigint): Promise<void>;
    payoutTransfers(idToAmt: Record<string, bigint>, payedAt: Date, solTx: string): Promise<void>;
    getLatestNodeOperatorEpoch(): Promise<{
        epochId: bigint;
        startedAt: Date;
        endedAt: Date;
        savedAt?: Date;
    } | undefined>;
    saveNodeOperatorEpoch(epochId: bigint, transfers: Transfer[], jobIds: number[], totalRndr: bigint): Promise<void>;
    updateBurned(epochId: bigint, burned: bigint, description: string): Promise<void>;
    fetchTransfersByWallet(f: {
        epochId?: number;
        payed?: boolean;
        typ: TransferType;
        address: string;
    }): Promise<Transfer[]>;
}
export declare const pgClient: (config: {
    database: string;
    host: string;
    user: string;
    password: string;
    port?: number;
    max?: number;
}, log?: RenderLogger) => PgClient;
//# sourceMappingURL=pgClient.d.ts.map